@@ -1,10 +1,11 @@
 import { showErrorMessage } from "@jupyterlab/apputils";
 import { URLExt, PathExt } from "@jupyterlab/coreutils";
-import { ISettingRegistry } from '@jupyterlab/settingregistry';
+import { ISettingRegistry } from "@jupyterlab/settingregistry";
 import { IFileBrowserFactory } from "@jupyterlab/filebrowser";
 import { ServerConnection } from "@jupyterlab/services";
 import { each } from "@lumino/algorithm";
 import { Menu } from "@lumino/widgets";
+import { archiveIcon, unarchiveIcon } from "./icon";
 const DIRECTORIES_URL = "directories";
 const EXTRACT_ARCHVE_URL = "extract-archive";
 var CommandIDs;
@@ -19,9 +20,7 @@ function downloadArchiveRequest(path, archiveFormat, followSymlinks, downloadHid
     let url = URLExt.join(baseUrl, DIRECTORIES_URL, URLExt.encodeParts(path));
     const fullurl = new URL(url);
     // Generate a random token.
-    const rand = () => Math.random()
-        .toString(36)
-        .substr(2);
+    const rand = () => Math.random().toString(36).substr(2);
     const token = (length) => (rand() + rand() + rand() + rand()).substr(0, length);
     fullurl.searchParams.append("archiveToken", token(20));
     fullurl.searchParams.append("archiveFormat", archiveFormat);
@@ -60,7 +59,7 @@ function extractArchiveRequest(path) {
     }
     url = fullurl.toString();
     const request = { method: "GET" };
-    return ServerConnection.makeRequest(url, request, settings).then(response => {
+    return ServerConnection.makeRequest(url, request, settings).then((response) => {
         if (response.status !== 200) {
             throw new ServerConnection.ResponseError(response);
         }
@@ -86,7 +85,7 @@ const extension = {
             ".tar.bz",
             ".tar.bz2",
             ".txz",
-            ".tar.xz"
+            ".tar.xz",
         ];
         let archiveFormat; // Default value read from settings
         let followSymlinks; // Default value read from settings
@@ -99,23 +98,23 @@ const extension = {
         const selectorNotDir = '.jp-DirListing-item[data-isdir="false"]';
         // Create submenus
         const archiveFolder = new Menu({
-            commands
+            commands,
         });
         archiveFolder.title.label = "Download As";
-        archiveFolder.title.iconClass = "jp-MaterialIcon jp-DownloadIcon";
+        archiveFolder.title.icon = archiveIcon;
         const archiveCurrentFolder = new Menu({
-            commands
+            commands,
         });
         archiveCurrentFolder.title.label = "Download Current Folder As";
-        archiveCurrentFolder.title.iconClass = "jp-MaterialIcon jp-DownloadIcon";
-        ["zip", "tar.bz2", "tar.gz", "tar.xz"].forEach(format => {
+        archiveCurrentFolder.title.icon = archiveIcon;
+        ["zip", "tar.bz2", "tar.gz", "tar.xz"].forEach((format) => {
             archiveFolder.addItem({
                 command: CommandIDs.downloadArchive,
-                args: { format }
+                args: { format },
             });
             archiveCurrentFolder.addItem({
                 command: CommandIDs.downloadArchiveCurrentFolder,
-                args: { format }
+                args: { format },
             });
         });
         // Reference to menu items
@@ -135,25 +134,25 @@ const extension = {
                             selector: selectorOnlyDir,
                             rank: 10,
                             type: "submenu",
-                            submenu: archiveFolder
+                            submenu: archiveFolder,
                         });
                         archiveCurrentFolderItem = app.contextMenu.addItem({
                             selector: selectorContent,
                             rank: 3,
                             type: "submenu",
-                            submenu: archiveCurrentFolder
+                            submenu: archiveCurrentFolder,
                         });
                     }
                     else {
                         archiveFolderItem = app.contextMenu.addItem({
                             command: CommandIDs.downloadArchive,
                             selector: selectorOnlyDir,
-                            rank: 10
+                            rank: 10,
                         });
                         archiveCurrentFolderItem = app.contextMenu.addItem({
                             command: CommandIDs.downloadArchiveCurrentFolder,
                             selector: selectorContent,
-                            rank: 3
+                            rank: 3,
                         });
                     }
                 }
@@ -163,8 +162,8 @@ const extension = {
         // Load the settings
         settingRegistry
             .load("@hadim/jupyter-archive:archive")
-            .then(settings => {
-            settings.changed.connect(settings => {
+            .then((settings) => {
+            settings.changed.connect((settings) => {
                 const newFormat = settings.get("format").composite;
                 updateFormat(newFormat, archiveFormat);
                 followSymlinks = settings.get("followSymlinks").composite;
@@ -175,16 +174,16 @@ const extension = {
             followSymlinks = settings.get("followSymlinks").composite;
             downloadHidden = settings.get("downloadHidden").composite;
         })
-            .catch(reason => {
+            .catch((reason) => {
             console.error(reason);
             showErrorMessage("Fail to read settings for '@hadim/jupyter-archive:archive'", reason);
         });
         // Add the 'downloadArchive' command to the file's menu.
         commands.addCommand(CommandIDs.downloadArchive, {
-            execute: args => {
+            execute: (args) => {
                 const widget = tracker.currentWidget;
                 if (widget) {
-                    each(widget.selectedItems(), item => {
+                    each(widget.selectedItems(), (item) => {
                         if (item.type == "directory") {
                             const format = args["format"];
                             downloadArchiveRequest(item.path, allowedArchiveExtensions.indexOf("." + format) >= 0
@@ -194,24 +193,24 @@ const extension = {
                     });
                 }
             },
-            iconClass: args => "format" in args ? "" : "jp-MaterialIcon jp-DownloadIcon",
-            label: args => {
+            icon: (args) => ("format" in args ? "" : archiveIcon),
+            label: (args) => {
                 const format = args["format"] || "";
                 const label = format.replace(".", " ").toLocaleUpperCase();
                 return label ? `${label} Archive` : "Download as an Archive";
-            }
+            },
         });
         // Add the 'extractArchive' command to the file's menu.
         commands.addCommand(CommandIDs.extractArchive, {
             execute: () => {
                 const widget = tracker.currentWidget;
                 if (widget) {
-                    each(widget.selectedItems(), item => {
+                    each(widget.selectedItems(), (item) => {
                         extractArchiveRequest(item.path);
                     });
                 }
             },
-            iconClass: "jp-MaterialIcon jp-DownCaretIcon",
+            icon: unarchiveIcon,
             isVisible: () => {
                 const widget = tracker.currentWidget;
                 let visible = false;
@@ -221,24 +220,25 @@ const extension = {
                     const splitName = basename.split(".");
                     let lastTwoParts = "";
                     if (splitName.length >= 2) {
-                        lastTwoParts = "." + splitName.splice(splitName.length - 2, 2).join(".");
+                        lastTwoParts =
+                            "." + splitName.splice(splitName.length - 2, 2).join(".");
                     }
                     visible =
-                        allowedArchiveExtensions.indexOf(PathExt.extname(basename)) >=
-                            0 || allowedArchiveExtensions.indexOf(lastTwoParts) >= 0;
+                        allowedArchiveExtensions.indexOf(PathExt.extname(basename)) >= 0 ||
+                            allowedArchiveExtensions.indexOf(lastTwoParts) >= 0;
                 }
                 return visible;
             },
-            label: "Extract Archive"
+            label: "Extract Archive",
         });
         app.contextMenu.addItem({
             command: CommandIDs.extractArchive,
             selector: selectorNotDir,
-            rank: 10
+            rank: 10,
         });
         // Add the 'downloadArchiveCurrentFolder' command to file browser content.
         commands.addCommand(CommandIDs.downloadArchiveCurrentFolder, {
-            execute: args => {
+            execute: (args) => {
                 const widget = tracker.currentWidget;
                 if (widget) {
                     const format = args["format"];
@@ -247,15 +247,15 @@ const extension = {
                         : archiveFormat, followSymlinks, downloadHidden);
                 }
             },
-            iconClass: args => "format" in args ? "" : "jp-MaterialIcon jp-DownloadIcon",
-            label: args => {
+            icon: (args) => ("format" in args ? "" : archiveIcon),
+            label: (args) => {
                 const format = args["format"] || "";
                 const label = format.replace(".", " ").toLocaleUpperCase();
                 return label
                     ? `${label} Archive`
                     : "Download Current Folder as an Archive";
-            }
+            },
         });
-    }
+    },
 };
 export default extension;
